@@ -48,54 +48,20 @@ class CfnDomain(
         id: str,
         *,
         access_policies: typing.Any = None,
-        advanced_options: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]
-        ] = None,
-        advanced_security_options: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable, "AdvancedSecurityOptionsInputProperty"
-            ]
-        ] = None,
-        cognito_options: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "CognitoOptionsProperty"]
-        ] = None,
-        domain_endpoint_options: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "DomainEndpointOptionsProperty"]
-        ] = None,
+        advanced_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]] = None,
+        advanced_security_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "AdvancedSecurityOptionsInputProperty"]] = None,
+        cognito_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CognitoOptionsProperty"]] = None,
+        domain_endpoint_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "DomainEndpointOptionsProperty"]] = None,
         domain_name: typing.Optional[str] = None,
-        ebs_options: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "EBSOptionsProperty"]
-        ] = None,
-        elasticsearch_cluster_config: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "ElasticsearchClusterConfigProperty"]
-        ] = None,
+        ebs_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "EBSOptionsProperty"]] = None,
+        elasticsearch_cluster_config: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "ElasticsearchClusterConfigProperty"]] = None,
         elasticsearch_version: typing.Optional[str] = None,
-        encryption_at_rest_options: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "EncryptionAtRestOptionsProperty"]
-        ] = None,
-        log_publishing_options: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.Mapping[
-                    str,
-                    typing.Union[
-                        aws_cdk.core.IResolvable, "LogPublishingOptionProperty"
-                    ],
-                ],
-            ]
-        ] = None,
-        node_to_node_encryption_options: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable, "NodeToNodeEncryptionOptionsProperty"
-            ]
-        ] = None,
-        snapshot_options: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "SnapshotOptionsProperty"]
-        ] = None,
+        encryption_at_rest_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "EncryptionAtRestOptionsProperty"]] = None,
+        log_publishing_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, typing.Union[aws_cdk.core.IResolvable, "LogPublishingOptionProperty"]]]] = None,
+        node_to_node_encryption_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "NodeToNodeEncryptionOptionsProperty"]] = None,
+        snapshot_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "SnapshotOptionsProperty"]] = None,
         tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]] = None,
-        vpc_options: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "VPCOptionsProperty"]
-        ] = None,
+        vpc_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "VPCOptionsProperty"]] = None,
     ) -> None:
         """Create a new ``AWS::Elasticsearch::Domain``.
 
@@ -137,34 +103,6 @@ class CfnDomain(
 
         jsii.create(CfnDomain, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: aws_cdk.core.Construct,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: aws_cdk.core.ICfnFinder,
-    ) -> "CfnDomain":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -242,9 +180,7 @@ class CfnDomain(
     @jsii.member(jsii_name="advancedOptions")
     def advanced_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]]:
         """``AWS::Elasticsearch::Domain.AdvancedOptions``.
 
         see
@@ -255,9 +191,7 @@ class CfnDomain(
     @advanced_options.setter
     def advanced_options(
         self,
-        value: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]],
     ) -> None:
         jsii.set(self, "advancedOptions", value)
 
@@ -265,9 +199,7 @@ class CfnDomain(
     @jsii.member(jsii_name="advancedSecurityOptions")
     def advanced_security_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, "AdvancedSecurityOptionsInputProperty"]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "AdvancedSecurityOptionsInputProperty"]]:
         """``AWS::Elasticsearch::Domain.AdvancedSecurityOptions``.
 
         see
@@ -278,11 +210,7 @@ class CfnDomain(
     @advanced_security_options.setter
     def advanced_security_options(
         self,
-        value: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable, "AdvancedSecurityOptionsInputProperty"
-            ]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "AdvancedSecurityOptionsInputProperty"]],
     ) -> None:
         jsii.set(self, "advancedSecurityOptions", value)
 
@@ -290,9 +218,7 @@ class CfnDomain(
     @jsii.member(jsii_name="cognitoOptions")
     def cognito_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, "CognitoOptionsProperty"]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CognitoOptionsProperty"]]:
         """``AWS::Elasticsearch::Domain.CognitoOptions``.
 
         see
@@ -303,9 +229,7 @@ class CfnDomain(
     @cognito_options.setter
     def cognito_options(
         self,
-        value: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "CognitoOptionsProperty"]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CognitoOptionsProperty"]],
     ) -> None:
         jsii.set(self, "cognitoOptions", value)
 
@@ -313,9 +237,7 @@ class CfnDomain(
     @jsii.member(jsii_name="domainEndpointOptions")
     def domain_endpoint_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, "DomainEndpointOptionsProperty"]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "DomainEndpointOptionsProperty"]]:
         """``AWS::Elasticsearch::Domain.DomainEndpointOptions``.
 
         see
@@ -326,9 +248,7 @@ class CfnDomain(
     @domain_endpoint_options.setter
     def domain_endpoint_options(
         self,
-        value: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "DomainEndpointOptionsProperty"]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "DomainEndpointOptionsProperty"]],
     ) -> None:
         jsii.set(self, "domainEndpointOptions", value)
 
@@ -361,9 +281,7 @@ class CfnDomain(
     @ebs_options.setter
     def ebs_options(
         self,
-        value: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "EBSOptionsProperty"]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "EBSOptionsProperty"]],
     ) -> None:
         jsii.set(self, "ebsOptions", value)
 
@@ -371,9 +289,7 @@ class CfnDomain(
     @jsii.member(jsii_name="elasticsearchClusterConfig")
     def elasticsearch_cluster_config(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, "ElasticsearchClusterConfigProperty"]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "ElasticsearchClusterConfigProperty"]]:
         """``AWS::Elasticsearch::Domain.ElasticsearchClusterConfig``.
 
         see
@@ -384,9 +300,7 @@ class CfnDomain(
     @elasticsearch_cluster_config.setter
     def elasticsearch_cluster_config(
         self,
-        value: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "ElasticsearchClusterConfigProperty"]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "ElasticsearchClusterConfigProperty"]],
     ) -> None:
         jsii.set(self, "elasticsearchClusterConfig", value)
 
@@ -408,9 +322,7 @@ class CfnDomain(
     @jsii.member(jsii_name="encryptionAtRestOptions")
     def encryption_at_rest_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, "EncryptionAtRestOptionsProperty"]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "EncryptionAtRestOptionsProperty"]]:
         """``AWS::Elasticsearch::Domain.EncryptionAtRestOptions``.
 
         see
@@ -421,9 +333,7 @@ class CfnDomain(
     @encryption_at_rest_options.setter
     def encryption_at_rest_options(
         self,
-        value: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "EncryptionAtRestOptionsProperty"]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "EncryptionAtRestOptionsProperty"]],
     ) -> None:
         jsii.set(self, "encryptionAtRestOptions", value)
 
@@ -431,15 +341,7 @@ class CfnDomain(
     @jsii.member(jsii_name="logPublishingOptions")
     def log_publishing_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.Mapping[
-                str,
-                typing.Union[aws_cdk.core.IResolvable, "LogPublishingOptionProperty"],
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, typing.Union[aws_cdk.core.IResolvable, "LogPublishingOptionProperty"]]]]:
         """``AWS::Elasticsearch::Domain.LogPublishingOptions``.
 
         see
@@ -450,17 +352,7 @@ class CfnDomain(
     @log_publishing_options.setter
     def log_publishing_options(
         self,
-        value: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.Mapping[
-                    str,
-                    typing.Union[
-                        aws_cdk.core.IResolvable, "LogPublishingOptionProperty"
-                    ],
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, typing.Union[aws_cdk.core.IResolvable, "LogPublishingOptionProperty"]]]],
     ) -> None:
         jsii.set(self, "logPublishingOptions", value)
 
@@ -468,9 +360,7 @@ class CfnDomain(
     @jsii.member(jsii_name="nodeToNodeEncryptionOptions")
     def node_to_node_encryption_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, "NodeToNodeEncryptionOptionsProperty"]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "NodeToNodeEncryptionOptionsProperty"]]:
         """``AWS::Elasticsearch::Domain.NodeToNodeEncryptionOptions``.
 
         see
@@ -481,11 +371,7 @@ class CfnDomain(
     @node_to_node_encryption_options.setter
     def node_to_node_encryption_options(
         self,
-        value: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable, "NodeToNodeEncryptionOptionsProperty"
-            ]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "NodeToNodeEncryptionOptionsProperty"]],
     ) -> None:
         jsii.set(self, "nodeToNodeEncryptionOptions", value)
 
@@ -493,9 +379,7 @@ class CfnDomain(
     @jsii.member(jsii_name="snapshotOptions")
     def snapshot_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, "SnapshotOptionsProperty"]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "SnapshotOptionsProperty"]]:
         """``AWS::Elasticsearch::Domain.SnapshotOptions``.
 
         see
@@ -506,9 +390,7 @@ class CfnDomain(
     @snapshot_options.setter
     def snapshot_options(
         self,
-        value: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "SnapshotOptionsProperty"]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "SnapshotOptionsProperty"]],
     ) -> None:
         jsii.set(self, "snapshotOptions", value)
 
@@ -527,9 +409,7 @@ class CfnDomain(
     @vpc_options.setter
     def vpc_options(
         self,
-        value: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "VPCOptionsProperty"]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "VPCOptionsProperty"]],
     ) -> None:
         jsii.set(self, "vpcOptions", value)
 
@@ -546,17 +426,9 @@ class CfnDomain(
         def __init__(
             self,
             *,
-            enabled: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
-            internal_user_database_enabled: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
-            master_user_options: typing.Optional[
-                typing.Union[
-                    aws_cdk.core.IResolvable, "CfnDomain.MasterUserOptionsProperty"
-                ]
-            ] = None,
+            enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
+            internal_user_database_enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
+            master_user_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.MasterUserOptionsProperty"]] = None,
         ) -> None:
             """
             :param enabled: ``CfnDomain.AdvancedSecurityOptionsInputProperty.Enabled``.
@@ -570,9 +442,7 @@ class CfnDomain(
             if enabled is not None:
                 self._values["enabled"] = enabled
             if internal_user_database_enabled is not None:
-                self._values[
-                    "internal_user_database_enabled"
-                ] = internal_user_database_enabled
+                self._values["internal_user_database_enabled"] = internal_user_database_enabled
             if master_user_options is not None:
                 self._values["master_user_options"] = master_user_options
 
@@ -601,11 +471,7 @@ class CfnDomain(
         @builtins.property
         def master_user_options(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable, "CfnDomain.MasterUserOptionsProperty"
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.MasterUserOptionsProperty"]]:
             """``CfnDomain.AdvancedSecurityOptionsInputProperty.MasterUserOptions``.
 
             see
@@ -638,9 +504,7 @@ class CfnDomain(
         def __init__(
             self,
             *,
-            enabled: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
+            enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
             identity_pool_id: typing.Optional[str] = None,
             role_arn: typing.Optional[str] = None,
             user_pool_id: typing.Optional[str] = None,
@@ -725,9 +589,7 @@ class CfnDomain(
         def __init__(
             self,
             *,
-            enforce_https: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
+            enforce_https: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
             tls_security_policy: typing.Optional[str] = None,
         ) -> None:
             """
@@ -788,9 +650,7 @@ class CfnDomain(
         def __init__(
             self,
             *,
-            ebs_enabled: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
+            ebs_enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
             iops: typing.Optional[jsii.Number] = None,
             volume_size: typing.Optional[jsii.Number] = None,
             volume_type: typing.Optional[str] = None,
@@ -881,20 +741,12 @@ class CfnDomain(
             self,
             *,
             dedicated_master_count: typing.Optional[jsii.Number] = None,
-            dedicated_master_enabled: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
+            dedicated_master_enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
             dedicated_master_type: typing.Optional[str] = None,
             instance_count: typing.Optional[jsii.Number] = None,
             instance_type: typing.Optional[str] = None,
-            zone_awareness_config: typing.Optional[
-                typing.Union[
-                    aws_cdk.core.IResolvable, "CfnDomain.ZoneAwarenessConfigProperty"
-                ]
-            ] = None,
-            zone_awareness_enabled: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
+            zone_awareness_config: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.ZoneAwarenessConfigProperty"]] = None,
+            zone_awareness_enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
         ) -> None:
             """
             :param dedicated_master_count: ``CfnDomain.ElasticsearchClusterConfigProperty.DedicatedMasterCount``.
@@ -974,11 +826,7 @@ class CfnDomain(
         @builtins.property
         def zone_awareness_config(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable, "CfnDomain.ZoneAwarenessConfigProperty"
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.ZoneAwarenessConfigProperty"]]:
             """``CfnDomain.ElasticsearchClusterConfigProperty.ZoneAwarenessConfig``.
 
             see
@@ -1017,9 +865,7 @@ class CfnDomain(
         def __init__(
             self,
             *,
-            enabled: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
+            enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
             kms_key_id: typing.Optional[str] = None,
         ) -> None:
             """
@@ -1079,9 +925,7 @@ class CfnDomain(
             self,
             *,
             cloud_watch_logs_log_group_arn: typing.Optional[str] = None,
-            enabled: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
+            enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
         ) -> None:
             """
             :param cloud_watch_logs_log_group_arn: ``CfnDomain.LogPublishingOptionProperty.CloudWatchLogsLogGroupArn``.
@@ -1092,9 +936,7 @@ class CfnDomain(
             """
             self._values = {}
             if cloud_watch_logs_log_group_arn is not None:
-                self._values[
-                    "cloud_watch_logs_log_group_arn"
-                ] = cloud_watch_logs_log_group_arn
+                self._values["cloud_watch_logs_log_group_arn"] = cloud_watch_logs_log_group_arn
             if enabled is not None:
                 self._values["enabled"] = enabled
 
@@ -1209,9 +1051,7 @@ class CfnDomain(
         def __init__(
             self,
             *,
-            enabled: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
+            enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
         ) -> None:
             """
             :param enabled: ``CfnDomain.NodeToNodeEncryptionOptionsProperty.Enabled``.
@@ -1262,9 +1102,7 @@ class CfnDomain(
             """
             self._values = {}
             if automated_snapshot_start_hour is not None:
-                self._values[
-                    "automated_snapshot_start_hour"
-                ] = automated_snapshot_start_hour
+                self._values["automated_snapshot_start_hour"] = automated_snapshot_start_hour
 
         @builtins.property
         def automated_snapshot_start_hour(self) -> typing.Optional[jsii.Number]:
@@ -1409,63 +1247,20 @@ class CfnDomainProps:
         self,
         *,
         access_policies: typing.Any = None,
-        advanced_options: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]
-        ] = None,
-        advanced_security_options: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                "CfnDomain.AdvancedSecurityOptionsInputProperty",
-            ]
-        ] = None,
-        cognito_options: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "CfnDomain.CognitoOptionsProperty"]
-        ] = None,
-        domain_endpoint_options: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable, "CfnDomain.DomainEndpointOptionsProperty"
-            ]
-        ] = None,
+        advanced_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]] = None,
+        advanced_security_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.AdvancedSecurityOptionsInputProperty"]] = None,
+        cognito_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.CognitoOptionsProperty"]] = None,
+        domain_endpoint_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.DomainEndpointOptionsProperty"]] = None,
         domain_name: typing.Optional[str] = None,
-        ebs_options: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "CfnDomain.EBSOptionsProperty"]
-        ] = None,
-        elasticsearch_cluster_config: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable, "CfnDomain.ElasticsearchClusterConfigProperty"
-            ]
-        ] = None,
+        ebs_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.EBSOptionsProperty"]] = None,
+        elasticsearch_cluster_config: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.ElasticsearchClusterConfigProperty"]] = None,
         elasticsearch_version: typing.Optional[str] = None,
-        encryption_at_rest_options: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable, "CfnDomain.EncryptionAtRestOptionsProperty"
-            ]
-        ] = None,
-        log_publishing_options: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.Mapping[
-                    str,
-                    typing.Union[
-                        aws_cdk.core.IResolvable,
-                        "CfnDomain.LogPublishingOptionProperty",
-                    ],
-                ],
-            ]
-        ] = None,
-        node_to_node_encryption_options: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                "CfnDomain.NodeToNodeEncryptionOptionsProperty",
-            ]
-        ] = None,
-        snapshot_options: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "CfnDomain.SnapshotOptionsProperty"]
-        ] = None,
+        encryption_at_rest_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.EncryptionAtRestOptionsProperty"]] = None,
+        log_publishing_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, typing.Union[aws_cdk.core.IResolvable, "CfnDomain.LogPublishingOptionProperty"]]]] = None,
+        node_to_node_encryption_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.NodeToNodeEncryptionOptionsProperty"]] = None,
+        snapshot_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.SnapshotOptionsProperty"]] = None,
         tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]] = None,
-        vpc_options: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "CfnDomain.VPCOptionsProperty"]
-        ] = None,
+        vpc_options: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.VPCOptionsProperty"]] = None,
     ) -> None:
         """Properties for defining a ``AWS::Elasticsearch::Domain``.
 
@@ -1512,9 +1307,7 @@ class CfnDomainProps:
         if log_publishing_options is not None:
             self._values["log_publishing_options"] = log_publishing_options
         if node_to_node_encryption_options is not None:
-            self._values[
-                "node_to_node_encryption_options"
-            ] = node_to_node_encryption_options
+            self._values["node_to_node_encryption_options"] = node_to_node_encryption_options
         if snapshot_options is not None:
             self._values["snapshot_options"] = snapshot_options
         if tags is not None:
@@ -1534,9 +1327,7 @@ class CfnDomainProps:
     @builtins.property
     def advanced_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]]:
         """``AWS::Elasticsearch::Domain.AdvancedOptions``.
 
         see
@@ -1547,11 +1338,7 @@ class CfnDomainProps:
     @builtins.property
     def advanced_security_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable, "CfnDomain.AdvancedSecurityOptionsInputProperty"
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.AdvancedSecurityOptionsInputProperty"]]:
         """``AWS::Elasticsearch::Domain.AdvancedSecurityOptions``.
 
         see
@@ -1562,9 +1349,7 @@ class CfnDomainProps:
     @builtins.property
     def cognito_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, "CfnDomain.CognitoOptionsProperty"]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.CognitoOptionsProperty"]]:
         """``AWS::Elasticsearch::Domain.CognitoOptions``.
 
         see
@@ -1575,11 +1360,7 @@ class CfnDomainProps:
     @builtins.property
     def domain_endpoint_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable, "CfnDomain.DomainEndpointOptionsProperty"
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.DomainEndpointOptionsProperty"]]:
         """``AWS::Elasticsearch::Domain.DomainEndpointOptions``.
 
         see
@@ -1599,9 +1380,7 @@ class CfnDomainProps:
     @builtins.property
     def ebs_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, "CfnDomain.EBSOptionsProperty"]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.EBSOptionsProperty"]]:
         """``AWS::Elasticsearch::Domain.EBSOptions``.
 
         see
@@ -1612,11 +1391,7 @@ class CfnDomainProps:
     @builtins.property
     def elasticsearch_cluster_config(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable, "CfnDomain.ElasticsearchClusterConfigProperty"
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.ElasticsearchClusterConfigProperty"]]:
         """``AWS::Elasticsearch::Domain.ElasticsearchClusterConfig``.
 
         see
@@ -1636,11 +1411,7 @@ class CfnDomainProps:
     @builtins.property
     def encryption_at_rest_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable, "CfnDomain.EncryptionAtRestOptionsProperty"
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.EncryptionAtRestOptionsProperty"]]:
         """``AWS::Elasticsearch::Domain.EncryptionAtRestOptions``.
 
         see
@@ -1651,17 +1422,7 @@ class CfnDomainProps:
     @builtins.property
     def log_publishing_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.Mapping[
-                str,
-                typing.Union[
-                    aws_cdk.core.IResolvable, "CfnDomain.LogPublishingOptionProperty"
-                ],
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, typing.Union[aws_cdk.core.IResolvable, "CfnDomain.LogPublishingOptionProperty"]]]]:
         """``AWS::Elasticsearch::Domain.LogPublishingOptions``.
 
         see
@@ -1672,11 +1433,7 @@ class CfnDomainProps:
     @builtins.property
     def node_to_node_encryption_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable, "CfnDomain.NodeToNodeEncryptionOptionsProperty"
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.NodeToNodeEncryptionOptionsProperty"]]:
         """``AWS::Elasticsearch::Domain.NodeToNodeEncryptionOptions``.
 
         see
@@ -1687,9 +1444,7 @@ class CfnDomainProps:
     @builtins.property
     def snapshot_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, "CfnDomain.SnapshotOptionsProperty"]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.SnapshotOptionsProperty"]]:
         """``AWS::Elasticsearch::Domain.SnapshotOptions``.
 
         see
@@ -1709,9 +1464,7 @@ class CfnDomainProps:
     @builtins.property
     def vpc_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, "CfnDomain.VPCOptionsProperty"]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnDomain.VPCOptionsProperty"]]:
         """``AWS::Elasticsearch::Domain.VPCOptions``.
 
         see
